# API Docs

## Source

### rabbitmq *(<a target="_blank" href="https://wso2.github.io/siddhi/documentation/siddhi-4.0/#sources">Source</a>)*

<p style="word-wrap: break-word">The rabbitmq source receives the events from the rabbitmq broker using the AMQP protocol. </p>

<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>
```
@source(type="rabbitmq", uri="<STRING>", heartbeat="<INT>", exchange.name="<STRING>", exchange.type="<STRING>", exchange.durable.enabled="<BOOL>", exchange.autodelete.enabled="<BOOL>", routing.key="<STRING>", headers="<STRING>", queue.name="<STRING>", queue.durable.enabled="<BOOL>", queue.exclusive.enabled="<BOOL>", queue.autodelete.enabled="<BOOL>", tls.enabled="<BOOL>", tls.truststore.path="<STRING>", tls.truststore.password="<STRING>", tls.truststore.type="<STRING>", tls.version="<STRING>", @map(...)))
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">uri</td>
        <td style="vertical-align: top; word-wrap: break-word">The uri that used to connects to an AMQP server. This is a mandatory parameter and if this is not specified, an error is logged in the CLI e.g., <code>amqp://guest:guest</code>, <code>amqp://guest:guest@localhost:5672</code> </td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">heartbeat</td>
        <td style="vertical-align: top; word-wrap: break-word">It defines after what period of time the peer TCP connection should be considered unreachable (down) by RabbitMQ and client libraries.</td>
        <td style="vertical-align: top">60</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">exchange.name</td>
        <td style="vertical-align: top; word-wrap: break-word">The name of the exchange, which decide what to do with a message it receives.If the exchange.name is already in the RabbitMQ server, then the system use that exchange.name instead of redeclaring</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">exchange.type</td>
        <td style="vertical-align: top; word-wrap: break-word">The type of the exchange.name. There are four different exchange types are available: <code>direct</code>, <code>fanout</code>, <code>topic</code> and <code>headers</code>. </td>
        <td style="vertical-align: top">direct</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">exchange.durable.enabled</td>
        <td style="vertical-align: top; word-wrap: break-word">Decide whether the exchange should remain declared even if the broker restarts. </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">exchange.autodelete.enabled</td>
        <td style="vertical-align: top; word-wrap: break-word">Decide whether to keep the exchange even if it is not used anymore. </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">routing.key</td>
        <td style="vertical-align: top; word-wrap: break-word">The key that the exchange looks at to decide how to route the message to queues. The routing key is like an address for the message. The routing.key must be initialized when the exchange.type = <code>direct</code> or exchange.type = <code>topic</code> </td>
        <td style="vertical-align: top">empty</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">headers</td>
        <td style="vertical-align: top; word-wrap: break-word">Headers of the message. The attributes used for routing are taken from the headers attribute. A message is considered matching if the value of the header equals the value specified upon binding </td>
        <td style="vertical-align: top">null</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">queue.name</td>
        <td style="vertical-align: top; word-wrap: break-word">A queue is a buffer that stores messages. If the queue.name is already in the RabbitMQ server, then the system use that queue.name instead of redeclaring it. If the queue.name is empty, then the system will used a unique queue name that is automatically generated by the rabbitmq server </td>
        <td style="vertical-align: top">system generated queue name</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">queue.durable.enabled</td>
        <td style="vertical-align: top; word-wrap: break-word">Decide whether the queue should remain declared even if the broker restarts</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">queue.exclusive.enabled</td>
        <td style="vertical-align: top; word-wrap: break-word">Decide whether the queue should be exclusive or should be consumable by other connections</td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">queue.autodelete.enabled</td>
        <td style="vertical-align: top; word-wrap: break-word">Decide whether to keep the queue even if it is not used anymore. </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tls.enabled</td>
        <td style="vertical-align: top; word-wrap: break-word">Used to establish an encrypted communication channel. The parameters <code>tls.truststore.path</code> and <code>tls.truststore.password</code> should be initialised when the parameter tls.enable = true: </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tls.truststore.path</td>
        <td style="vertical-align: top; word-wrap: break-word">The file path to the location of the truststore of the client that sends the RabbitMQ events through 'AMQP' protocol. A custom client-truststore can be specified if required. If custom truststore is not specified then the system uses the default client-trustore in the <code>${carbon.home}/resources/security</code> directory.</td>
        <td style="vertical-align: top">${carbon.home}/resources/security/client-truststore.jks</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tls.truststore.password</td>
        <td style="vertical-align: top; word-wrap: break-word">The password for the client-truststore. A custom password can be specified if required. If no custom password is specified, then the system uses 'wso2carbon' as the default password.</td>
        <td style="vertical-align: top">wso2carbon</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tls.truststore.type</td>
        <td style="vertical-align: top; word-wrap: break-word">The type of the truststore.</td>
        <td style="vertical-align: top">JKS</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tls.version</td>
        <td style="vertical-align: top; word-wrap: break-word">The version of the tls/ssl.</td>
        <td style="vertical-align: top">SSL</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
@App:name('TestExecutionPlan') 
define stream FooStream (symbol string, price float, volume long); 
@info(name = 'query1') 
@source(type ='rabbitmq', uri = 'amqp://guest:guest@localhost:5672', exchange.name = 'direct', routing.key= 'direct', @map(type='xml'))Define stream BarStream (symbol string, price float, volume long);
from FooStream select symbol, price, volume insert into BarStream;

```
<p style="word-wrap: break-word">The following query will receive events from  'direct' exchange with exchange type <code>direct</code> and routing key <code>directTest</code></p>

## Sink

### rabbitmq *(<a target="_blank" href="https://wso2.github.io/siddhi/documentation/siddhi-4.0/#sinks">Sink</a>)*

<p style="word-wrap: break-word">The rabbitmq sink pushes the events into a rabbitmq broker using the AMQP protocol</p>

<span id="syntax" class="md-typeset" style="display: block; font-weight: bold;">Syntax</span>
```
@sink(type="rabbitmq", uri="<STRING>", heartbeat="<INT>", exchange.name="<STRING>", exchange.type="<STRING>", exchange.durable.enabled="<BOOL>", exchange.autodelete.enabled="<BOOL>", delivery.mode="<INT>", content.type="<STRING>", content.encoding="<STRING>", priority="<INT>", correlation.id="<STRING>", reply.to="<STRING>", expiration="<STRING>", message.id="<STRING>", timestamp="<STRING>", type="<STRING>", user.id="<STRING>", app.id="<STRING>", routing.key="<STRING>", headers="<STRING>", tls.enabled="<BOOL>", tls.truststore.path="<STRING>", tls.truststore.password="<STRING>", tls.truststore.type="<STRING>", tls.version="<STRING>", @map(...)))
```

<span id="query-parameters" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">QUERY PARAMETERS</span>
<table>
    <tr>
        <th>Name</th>
        <th style="min-width: 20em">Description</th>
        <th>Default Value</th>
        <th>Possible Data Types</th>
        <th>Optional</th>
        <th>Dynamic</th>
    </tr>
    <tr>
        <td style="vertical-align: top">uri</td>
        <td style="vertical-align: top; word-wrap: break-word">The uri that used to connects to an AMQP server. This is a mandatory parameter and if it is not specified, an error is logged in the CLI e.g., <code>amqp://guest:guest</code>, <code>amqp://guest:guest@localhost:5672</code> </td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">heartbeat</td>
        <td style="vertical-align: top; word-wrap: break-word">It defines after what period of time the peer TCP connection should be considered unreachable (down) by RabbitMQ and client libraries.</td>
        <td style="vertical-align: top">60</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">exchange.name</td>
        <td style="vertical-align: top; word-wrap: break-word">The name of the exchange, which decide what to do with a message it receives.If the exchange.name is already in the RabbitMQ server, then the system use that exchange.name instead of redeclaring.</td>
        <td style="vertical-align: top"></td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">No</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">exchange.type</td>
        <td style="vertical-align: top; word-wrap: break-word">The type of the exchange.name. There are four different exchange types are available: <code>direct</code>, <code>fanout</code>, <code>topic</code> and <code>headers</code>. </td>
        <td style="vertical-align: top">direct</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">exchange.durable.enabled</td>
        <td style="vertical-align: top; word-wrap: break-word">Decide whether the exchange should remain declared even if the broker restarts. </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">exchange.autodelete.enabled</td>
        <td style="vertical-align: top; word-wrap: break-word">Decide whether to keep the exchange even if it is not used anymore. </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">delivery.mode</td>
        <td style="vertical-align: top; word-wrap: break-word">Decide whether the connection should be persistent or not. delivery.mode'svalue should be either 1 or 2. If the delivery.mode = 1, then the connection is not persistent. If the delivery.mode = 2, then the connection is persistent</td>
        <td style="vertical-align: top">1</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">content.type</td>
        <td style="vertical-align: top; word-wrap: break-word">Message content type, value should be MIME content type.</td>
        <td style="vertical-align: top">null</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">content.encoding</td>
        <td style="vertical-align: top; word-wrap: break-word">Message content encoding, value should be MIME content encoding.</td>
        <td style="vertical-align: top">null</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">priority</td>
        <td style="vertical-align: top; word-wrap: break-word">Message priority, value should be within the range 0 to 9</td>
        <td style="vertical-align: top">0</td>
        <td style="vertical-align: top">INT</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">correlation.id</td>
        <td style="vertical-align: top; word-wrap: break-word">Message correlated to this one, e.g. what request this message is a reply to. A request comes in, message describing the task is pushed to queue by the frontend server. After that the frontend server blocks to wait for response message with the same correlation id. A pool of worker machines are listening on queue and one of them picks up the task, performs it and returns the result as message. Once a message with right correlation id comes in, frontend server continues to return the response to the caller. </td>
        <td style="vertical-align: top">null</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">reply.to</td>
        <td style="vertical-align: top; word-wrap: break-word">This is an anonymous exclusive callback Queue. When the RabbitMQ receives a message with the property 'reply.to', it will send the response to the mentioned queue. Commonly used to name a reply queue (or any other identifier that helps a consumer application to direct its response).</td>
        <td style="vertical-align: top">null</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">expiration</td>
        <td style="vertical-align: top; word-wrap: break-word">Expiration time after which the message will be deleted. The value of the expiration field describes the TTL period in milliseconds.</td>
        <td style="vertical-align: top">null</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">message.id</td>
        <td style="vertical-align: top; word-wrap: break-word">Message identifier. If applications need to identify messages, it is recommended that they use this attribute instead of putting it into the message payload. </td>
        <td style="vertical-align: top">null</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">timestamp</td>
        <td style="vertical-align: top; word-wrap: break-word">Timestamp of the moment when message was sent. If the timestamp is empty, then the system will automatically generate the current date and time as the timestamp value. The format of the timestamp is that dd/mm/yyyy.</td>
        <td style="vertical-align: top">current timestamp</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">type</td>
        <td style="vertical-align: top; word-wrap: break-word">Message type, e.g. what type of event or command this message represents.</td>
        <td style="vertical-align: top">null</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">user.id</td>
        <td style="vertical-align: top; word-wrap: break-word">Optional user ID. Verified by RabbitMQ against the actual connection username. </td>
        <td style="vertical-align: top">null</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">app.id</td>
        <td style="vertical-align: top; word-wrap: break-word">Identifier of the application that produced the message.</td>
        <td style="vertical-align: top">null</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">routing.key</td>
        <td style="vertical-align: top; word-wrap: break-word">The key that the exchange looks at to decide how to route the message to queues. The routing key is like an address for the message. </td>
        <td style="vertical-align: top">empty</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">headers</td>
        <td style="vertical-align: top; word-wrap: break-word">Headers of the message. The attributes used for routing are taken from the headers attribute. A message is considered matching if the value of the header equals the value specified upon binding </td>
        <td style="vertical-align: top">null</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">Yes</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tls.enabled</td>
        <td style="vertical-align: top; word-wrap: break-word">Used to establish an encrypted communication channel. The parameters <code>tls.truststore.path</code> and <code>tls.truststore.password</code> should be initialised when the parameter tls.enable = true: </td>
        <td style="vertical-align: top">false</td>
        <td style="vertical-align: top">BOOL</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tls.truststore.path</td>
        <td style="vertical-align: top; word-wrap: break-word">The file path to the location of the truststore of the client that sends the RabbitMQ events through 'AMQP' protocol. A custom client-truststore can be specified if required. If custom truststore is not specified then the system uses the default client-trustore in the <code>${carbon.home}/resources/security</code> directory.</td>
        <td style="vertical-align: top">${carbon.home}/resources/security/client-truststore.jks</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tls.truststore.password</td>
        <td style="vertical-align: top; word-wrap: break-word">The password for the client-truststore. A custom password can be specified if required. If no custom password is specified, then the system uses 'wso2carbon' as the default password.</td>
        <td style="vertical-align: top">wso2carbon</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tls.truststore.type</td>
        <td style="vertical-align: top; word-wrap: break-word">The type of the truststore.</td>
        <td style="vertical-align: top">JKS</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
    <tr>
        <td style="vertical-align: top">tls.version</td>
        <td style="vertical-align: top; word-wrap: break-word">The version of the tls/ssl.</td>
        <td style="vertical-align: top">SSL</td>
        <td style="vertical-align: top">STRING</td>
        <td style="vertical-align: top">Yes</td>
        <td style="vertical-align: top">No</td>
    </tr>
</table>

<span id="examples" class="md-typeset" style="display: block; font-weight: bold;">Examples</span>
<span id="example-1" class="md-typeset" style="display: block; color: rgba(0, 0, 0, 0.54); font-size: 12.8px; font-weight: bold;">EXAMPLE 1</span>
```
@App:name('TestExecutionPlan') 
define stream FooStream (symbol string, price float, volume long); 
@info(name = 'query1') 
@sink(type ='rabbitmq', uri = 'amqp://guest:guest@localhost:5672', exchange.name = 'direct', routing.key= 'direct', @map(type='xml'))Define stream BarStream (symbol string, price float, volume long);
from FooStream select symbol, price, volume insert into BarStream;

```
<p style="word-wrap: break-word">The following query will publish events to 'direct' exchange with exchange type <code>direct</code> and routing key <code>directTest</code></p>

